@@ -11,20 +11,28 @@ import py
 import os
 import sqlobject
 
+try:
+    import pkg_resources
+except ImportError: # Python 2.2
+    pass
+else:
+    pkg_resources.require('SQLObject')
+
 connectionShortcuts = {
     'mysql': 'mysql://test@localhost/test',
     'dbm': 'dbm:///data',
     'postgres': 'postgres:///test',
     'postgresql': 'postgres:///test',
+    'rdbhost': 'rdhbost://role:authcode@www.rdbhost.com/',
     'pygresql': 'pygresql://localhost/test',
-    'sqlite': 'sqlite:///%s/data/sqlite.data' % os.getcwd(),
+    'sqlite': 'sqlite:/:memory:',
     'sybase': 'sybase://test:test123@sybase/test?autoCommit=0',
     'firebird': 'firebird://sysdba:masterkey@localhost/var/lib/firebird/data/test.gdb',
     'mssql': 'mssql://sa:@127.0.0.1/test'
     }
 
-Option = py.test.Config.Option
-option = py.test.Config.addoptions(
+Option = py.test.config.Option
+option = py.test.config.addoptions(
     "SQLObject options",
     Option('-D', '--Database',
            action="store", dest="Database", default='sqlite',
@@ -38,7 +46,12 @@ option = py.test.Config.addoptions(
     Option('-O', '--SQL-output',
            action="store_true", dest="show_sql_output", default=False,
            help="Show output from SQL statements (when capturing "
-           "stdout the output is only displayed when a test fails)"))
+           "stdout the output is only displayed when a test fails)"),
+    Option('-E', '--events',
+           action="store_true", dest="debug_events", default=False,
+           help="Debug events (print information about events as they are "
+           "sent)"),
+    )
 
 class SQLObjectClass(py.test.collect.Class):
     def run(self):
@@ -48,3 +61,8 @@ class SQLObjectClass(py.test.collect.Class):
         return super(SQLObjectClass, self).run()
 
 Class = SQLObjectClass
+
+def setup_tests():
+    if option.debug_events:
+        from sqlobject import events
+        events.debug_events()
