@@ -24,13 +24,9 @@ try:
 except ImportError:
     NumericType = None
 
+from decimal import Decimal
 from types import ClassType, InstanceType, NoneType
 
-try:
-    from decimal import Decimal
-except ImportError:
-    Decimal = None
-
 ########################################
 ## Quoting
 ########################################
@@ -87,7 +83,7 @@ def StringLikeConverter(value, db):
     elif isinstance(value, buffer):
         value = str(value)
 
-    if db in ('mysql', 'postgres'):
+    if db in ('mysql', 'postgres', 'rdbhost'):
         for orig, repl in sqlStringReplace:
             value = value.replace(orig, repl)
     elif db in ('sqlite', 'firebird', 'sybase', 'maxdb', 'mssql'):
@@ -115,7 +111,7 @@ if NumericType:
     registerConverter(NumericType, IntConverter)
 
 def BoolConverter(value, db):
-    if db in ('postgres',):
+    if db in ('postgres', 'rdbhost'):
         if value:
             return "'t'"
         else:
@@ -155,21 +151,12 @@ def SequenceConverter(value, db):
 registerConverter(tuple, SequenceConverter)
 registerConverter(list, SequenceConverter)
 registerConverter(dict, SequenceConverter)
-try:
-    set, frozenset
-except NameError:
-    pass
-else:
-    registerConverter(set, SequenceConverter)
-    registerConverter(frozenset, SequenceConverter)
+registerConverter(set, SequenceConverter)
+registerConverter(frozenset, SequenceConverter)
 if sys.version_info[:3] < (2, 6, 0): # Module sets was deprecated in Python 2.6
-    try:
-        from sets import Set, ImmutableSet
-    except ImportError:
-        pass
-    else:
-        registerConverter(Set, SequenceConverter)
-        registerConverter(ImmutableSet, SequenceConverter)
+   from sets import Set, ImmutableSet
+   registerConverter(Set, SequenceConverter)
+   registerConverter(ImmutableSet, SequenceConverter)
 
 if hasattr(time, 'struct_time'):
     def StructTimeConverter(value, db):
@@ -194,12 +181,19 @@ def TimeConverter(value, db):
 
 registerConverter(datetime.time, TimeConverter)
 
-if Decimal:
-    def DecimalConverter(value, db):
-        # See http://mail.python.org/pipermail/python-dev/2008-March/078189.html
-        return str(value.to_eng_string()) # Convert to str to work around a bug in Python 2.5.2
+def DecimalConverter(value, db):
+    # See http://mail.python.org/pipermail/python-dev/2008-March/078189.html
+    return str(value.to_eng_string()) # Convert to str to work around a bug in Python 2.5.2
 
-    registerConverter(Decimal, DecimalConverter)
+registerConverter(Decimal, DecimalConverter)
+
+def TimedeltaConverter(value, db):
+    
+    return """INTERVAL '%d days %d seconds'""" % \
+        (value.days, value.seconds)
+
+registerConverter(datetime.timedelta, TimedeltaConverter)
+        
 
 def sqlrepr(obj, db=None):
     try:
