@@ -1,13 +1,15 @@
-import sqlbuilder
-NoDefault = sqlbuilder.NoDefault
-import styles
+from itertools import count
 import classregistry
-from col import popKey
 import events
+import styles
+import sqlbuilder
 
 __all__ = ['MultipleJoin', 'SQLMultipleJoin', 'RelatedJoin', 'SQLRelatedJoin',
            'SingleJoin', 'ManyToMany', 'OneToMany']
 
+creationOrder = count()
+NoDefault = sqlbuilder.NoDefault
+
 def getID(obj):
     try:
         return obj.id
@@ -19,10 +21,8 @@ class Join(object):
     def __init__(self, otherClass=None, **kw):
         kw['otherClass'] = otherClass
         self.kw = kw
-        if self.kw.has_key('joinMethodName'):
-            self._joinMethodName = popKey(self.kw, 'joinMethodName')
-        else:
-            self._joinMethodName = None
+        self._joinMethodName = self.kw.pop('joinMethodName', None)
+        self.creationOrder = creationOrder.next()
 
     def _set_joinMethodName(self, value):
         assert self._joinMethodName == value or self._joinMethodName is None, "You have already given an explicit joinMethodName (%s), and you are now setting it to %s" % (self._joinMethodName, value)
@@ -38,7 +38,8 @@ class Join(object):
         if self.kw.has_key('joinMethodName'):
             self._joinMethodName = self.kw['joinMethodName']
             del self.kw['joinMethodName']
-        return self.baseClass(soClass=soClass,
+        return self.baseClass(creationOrder=self.creationOrder,
+                              soClass=soClass,
                               joinDef=self,
                               joinMethodName=self._joinMethodName,
                               **self.kw)
@@ -49,12 +50,14 @@ class Join(object):
 class SOJoin(object):
 
     def __init__(self,
+                 creationOrder,
                  soClass=None,
                  otherClass=None,
                  joinColumn=None,
                  joinMethodName=None,
                  orderBy=NoDefault,
                  joinDef=None):
+        self.creationOrder = creationOrder
         self.soClass = soClass
         self.joinDef = joinDef
         self.otherClassName = otherClass
@@ -62,7 +65,7 @@ class SOJoin(object):
             otherClass, self._setOtherClass)
         self.joinColumn = joinColumn
         self.joinMethodName = joinMethodName
-        self.orderBy = orderBy
+        self._orderBy = orderBy
         if not self.joinColumn:
             # Here we set up the basic join, which is
             # one-to-many, where the other class points to
@@ -70,6 +73,12 @@ class SOJoin(object):
             self.joinColumn = styles.getStyle(
                 self.soClass).tableReference(self.soClass.sqlmeta.table)
 
+    def orderBy(self):
+        if self._orderBy is NoDefault:
+            self._orderBy = self.otherClass.sqlmeta.defaultOrder
+        return self._orderBy
+    orderBy = property(orderBy)
+
     def _setOtherClass(self, cls):
         self.otherClass = cls
 
@@ -77,14 +86,12 @@ class SOJoin(object):
         return False
 
     def _applyOrderBy(self, results, defaultSortClass):
-        if self.orderBy is NoDefault:
-            self.orderBy = defaultSortClass.sqlmeta.defaultOrder
         if self.orderBy is not None:
             results.sort(sorter(self.orderBy))
         return results
 
 def sorter(orderBy):
-    if isinstance(orderBy, tuple) or isinstance(orderBy, list):
+    if isinstance(orderBy, (tuple, list)):
         if len(orderBy) == 1:
             orderBy = orderBy[0]
         else:
@@ -148,6 +155,12 @@ class SOMultipleJoin(SOJoin):
             conn = None
         return self._applyOrderBy([self.otherClass.get(id, conn) for (id,) in ids if id is not None], self.otherClass)
 
+    def _dbNameToPythonName(self):
+        for column in self.otherClass.sqlmeta.columns.values():
+            if column.dbName == self.joinColumn:
+                return column.name
+        return self.soClass.sqlmeta.style.dbColumnToPythonAttr(self.joinColumn)
+
 class MultipleJoin(Join):
     baseClass = SOMultipleJoin
 
@@ -158,9 +171,8 @@ class SOSQLMultipleJoin(SOMultipleJoin):
             conn = inst._connection
         else:
             conn = None
-        results = self.otherClass.select(getattr(self.otherClass.q, self.soClass.sqlmeta.style.dbColumnToPythonAttr(self.joinColumn)) == inst.id, connection=conn)
-        if self.orderBy is NoDefault:
-            self.orderBy = self.otherClass.sqlmeta.defaultOrder
+        pythonColumn = self._dbNameToPythonName()
+        results = self.otherClass.select(getattr(self.otherClass.q, pythonColumn) == inst.id, connection=conn)
         return results.orderBy(self.orderBy)
 
 class SQLMultipleJoin(Join):
@@ -235,6 +247,9 @@ class OtherTableToJoin(sqlbuilder.SQLExpression):
         self.interTable = interTable
         self.joinColumn = joinColumn
 
+    def tablesUsedImmediate(self):
+        return [self.otherTable, self.interTable]
+
     def __sqlrepr__(self, db):
         return '%s.%s = %s.%s' % (self.otherTable, self.otherIdName, self.interTable, self.joinColumn)
 
@@ -244,7 +259,10 @@ class JoinToTable(sqlbuilder.SQLExpression):
         self.idName = idName
         self.interTable = interTable
         self.joinColumn = joinColumn
-    
+
+    def tablesUsedImmediate(self):
+        return [self.table, self.interTable]
+
     def __sqlrepr__(self, db):
         return '%s.%s = %s.%s' % (self.interTable, self.joinColumn, self.table, self.idName)
 
@@ -254,6 +272,9 @@ class TableToId(sqlbuilder.SQLExpression):
         self.idName = idName
         self.idValue = idValue
 
+    def tablesUsedImmediate(self):
+        return [self.table]
+
     def __sqlrepr__(self, db):
         return '%s.%s = %s' % (self.table, self.idName, self.idValue)
 
@@ -265,7 +286,7 @@ class SOSQLRelatedJoin(SORelatedJoin):
             conn = None
         results = self.otherClass.select(sqlbuilder.AND(
             OtherTableToJoin(
-                self.otherClass.sqlmeta.table, self.otherClass.sqlmeta.idName, 
+                self.otherClass.sqlmeta.table, self.otherClass.sqlmeta.idName,
                 self.intermediateTable, self.otherColumn
             ),
             JoinToTable(
@@ -275,8 +296,6 @@ class SOSQLRelatedJoin(SORelatedJoin):
             TableToId(self.soClass.sqlmeta.table, self.soClass.sqlmeta.idName, inst.id),
         ), clauseTables=(self.soClass.sqlmeta.table, self.otherClass.sqlmeta.table, self.intermediateTable),
         connection=conn)
-        if self.orderBy is NoDefault:
-            self.orderBy = self.otherClass.sqlmeta.defaultOrder
         return results.orderBy(self.orderBy)
 
 class SQLRelatedJoin(RelatedJoin):
@@ -288,7 +307,7 @@ def capitalize(name):
 class SOSingleJoin(SOMultipleJoin):
 
     def __init__(self, **kw):
-        self.makeDefault = popKey(kw, 'makeDefault', False)
+        self.makeDefault = kw.pop('makeDefault', False)
         SOMultipleJoin.__init__(self, **kw)
 
     def performJoin(self, inst):
@@ -296,7 +315,7 @@ class SOSingleJoin(SOMultipleJoin):
             conn = inst._connection
         else:
             conn = None
-        pythonColumn = self.soClass.sqlmeta.style.dbColumnToPythonAttr(self.joinColumn)
+        pythonColumn = self._dbNameToPythonName()
         results = self.otherClass.select(
             getattr(self.otherClass.q, pythonColumn) == inst.id,
             connection=conn
@@ -378,7 +397,7 @@ class SOManyToMany(object):
             & (sqlbuilder.Field(self.intermediateTable, self.joinColumn)
                == obj.id))
         select = self.otherClass.select(query)
-        return _ManyToManySelectWrapper(obj, self, select)        
+        return _ManyToManySelectWrapper(obj, self, select)
 
     def event_CreateTableSignal(self, soClass, connection, extra_sql,
                                 post_funcs):
@@ -402,14 +421,14 @@ class ManyToMany(boundattributes.BoundFactory):
     joinColumn = None
     otherColumn = None
     createJoinTable = True
-    
+
 class _ManyToManySelectWrapper(object):
 
     def __init__(self, forObject, join, select):
         self.forObject = forObject
         self.join = join
         self.select = select
-    
+
     def __getattr__(self, attr):
         # @@: This passes through private variable access too... should it?
         # Also magic methods, like __str__
@@ -447,7 +466,7 @@ class _ManyToManySelectWrapper(object):
         obj = self.join.otherClass(**kw)
         self.add(obj)
         return obj
-                
+
 class SOOneToMany(object):
 
     def __init__(self, soClass, name, join, joinColumn, **attrs):
@@ -493,7 +512,7 @@ class _OneToManySelectWrapper(object):
         self.forObject = forObject
         self.join = join
         self.select = select
-    
+
     def __getattr__(self, attr):
         # @@: This passes through private variable access too... should it?
         # Also magic methods, like __str__
@@ -514,4 +533,3 @@ class _OneToManySelectWrapper(object):
     def create(self, **kw):
         kw[self.join.joinColumn] = self.forObject.id
         return self.join.otherClass(**kw)
-    
