@@ -11,11 +11,10 @@ connection creation sample::
 
     __connection__ = DBConnection.maxdbConnection(
         host=hostname, database=dbname,
-        user=user_name, password=user_password,autoCommit=1,debug=1)
+        user=user_name, password=user_password, autoCommit=1, debug=1)
 """
 from sqlobject.dbconnection import DBAPI
 from sqlobject import col
-dbapi = None
 
 
 
@@ -60,29 +59,28 @@ class MaxdbConnection(DBAPI):
     dbName = 'maxdb'
     schemes = [dbName]
 
-    def __init__ (self, user, password, database,
-                  host='', autoCommit=1, sqlmode='internal',
+    def __init__ (self, host='', port=None, user=None, password=None,
+                  database=None, autoCommit=1, sqlmode='internal',
                   isolation=None, timeout=None, **kw):
-        global dbapi
-        if dbapi is None:
-            from sapdb import dbapi
+        from sapdb import dbapi
         self.module = dbapi
-        self.autoCommit = autoCommit
+        self.host      = host
+        self.port      = port
         self.user      = user
         self.password  = password
-        self.database  = database
-        self.host      = host
+        self.db        = database
+        self.autoCommit = autoCommit
         self.sqlmode   = sqlmode
         self.isolation = isolation
         self.timeout   = timeout
 
         DBAPI.__init__(self, **kw)
 
-    def connectionFromURI(cls, uri):
-        auth, password, host, port, path, args = cls._parseURI(uri)
+    def _connectionFromParams(cls, auth, password, host, port, path, args):
         path = path.replace('/', os.path.sep)
-        return cls(host, db=path, user=auth, password=password, **args)
-    connectionFromURI = classmethod(connectionFromURI)
+        return cls(host, port, user=auth, password=password,
+            database=path, **args)
+    _connectionFromParams = classmethod(_connectionFromParams)
 
     def _getConfigParams(self,sqlmode,auto):
         autocommit='off'
@@ -99,9 +97,8 @@ class MaxdbConnection(DBAPI):
 
     def _setAutoCommit(self, conn, auto):
         conn.close()
-        conn.__init__(self.user, self.password, self.database,
-                      self.host,
-                      **self._getConfigParams(self.sqlmode,auto))
+        conn.__init__(self.user, self.password, self.db, self.host,
+                      **self._getConfigParams(self.sqlmode, auto))
 
     def createSequenceName(self,table):
         """
@@ -114,9 +111,9 @@ class MaxdbConnection(DBAPI):
         return '%s_SEQ'%(table[:SAPDBMAX_ID_LENGTH -4])
 
     def makeConnection(self):
-        conn = dbapi.Connection(
-            self.user, self.password, self.database, self.host,
-            **self._getConfigParams(self.sqlmode,self.autoCommit))
+        conn = self.module.Connection(
+            self.user, self.password, self.db, self.host,
+            **self._getConfigParams(self.sqlmode, self.autoCommit))
         return conn
 
     def _queryInsertID(self, conn, soInstance, id, names, values):
@@ -136,7 +133,7 @@ class MaxdbConnection(DBAPI):
             self.printDebug(conn, id, 'QueryIns', 'result')
         return id
 
-    def sqlAddLimit(self,query,limit):
+    def sqlAddLimit(cls,query,limit):
         sql = query
         sql = sql.replace("SELECT","SELECT ROWNO, ")
         if sql.find('WHERE') != -1:
@@ -144,12 +141,14 @@ class MaxdbConnection(DBAPI):
         else:
             sql = sql + 'WHERE ' + limit
         return sql
+    sqlAddLimit = classmethod(sqlAddLimit)
 
-    def _queryAddLimitOffset(self, query, start, end):
+    def _queryAddLimitOffset(cls, query, start, end):
         if start:
             raise LowerBoundOfSliceIsNotSupported
         limit = ' ROWNO   <= %d ' % (end)
-        return self.sqlAddLimit(query,limit)
+        return cls.sqlAddLimit(query,limit)
+    _queryAddLimitOffset = classmethod(_queryAddLimitOffset)
 
 
     def createTable(self, soClass):
@@ -255,7 +254,7 @@ class MaxdbConnection(DBAPI):
             # id is defined as primary key --> ok
             # We let sqlobject raise error if the 'id' is used for another column
             field_name = field.lower()
-            if field_name == 'id' and  pkmap[field_name]:
+            if (field_name == soClass.sqlmeta.idName) and pkmap[field_name]:
                 continue
 
             colClass, kw = self.guessClass(data_type,data_len,data_scale)
