@@ -1,26 +1,27 @@
 from sqlobject.dbconnection import DBAPI
 from sqlobject import col
-Sybase = None
 
 class SybaseConnection(DBAPI):
 
     supportTransactions = False
     dbName = 'sybase'
     schemes = [dbName]
+    NumericType = None
 
-    def __init__(self, db, user, password='', host='localhost',
+    def __init__(self, db, user, password='', host='localhost', port=None,
                  locking=1, **kw):
         db = db.strip('/')
-        global Sybase
-        if Sybase is None:
-            import Sybase
-            Sybase._ctx.debug = 0
+        import Sybase
+        Sybase._ctx.debug = 0
+        if SybaseConnection.NumericType is None:
             from Sybase import NumericType
+            SybaseConnection.NumericType = NumericType
             from sqlobject.converters import registerConverter, IntConverter
             registerConverter(NumericType, IntConverter)
         self.module = Sybase
         self.locking = int(locking)
         self.host = host
+        self.port = port
         self.db = db
         self.user = user
         self.password = password
@@ -32,11 +33,10 @@ class SybaseConnection(DBAPI):
         kw['autoCommit'] = autoCommit
         DBAPI.__init__(self, **kw)
 
-    def connectionFromURI(cls, uri):
-        user, password, host, port, path, args = cls._parseURI(uri)
-        return cls(user=user, password=password, host=host or 'localhost',
-                   db=path, **args)
-    connectionFromURI = classmethod(connectionFromURI)
+    def _connectionFromParams(cls, user, password, host, port, path, args):
+        return cls(user=user, password=password,
+                   host=host or 'localhost', port=port, db=path, **args)
+    _connectionFromParams = classmethod(_connectionFromParams)
 
     def insert_id(self, conn):
         """
@@ -48,7 +48,7 @@ class SybaseConnection(DBAPI):
         return c.fetchone()[0]
 
     def makeConnection(self):
-        return Sybase.connect(self.host, self.user, self.password,
+        return self.module.connect(self.host, self.user, self.password,
                               database=self.db, auto_commit=self.autoCommit,
                               locking=self.locking)
 
