@@ -10,6 +10,12 @@ import py
 import sqlobject
 import sqlobject.conftest as conftest
 
+try:
+    import logging
+    loggingModuleAvailable = True
+except ImportError:
+    loggingModuleAvailable = False
+
 if sys.platform[:3] == "win":
     def getcwd():
         return os.getcwd().replace(':', '|')
@@ -32,16 +38,15 @@ and you can use it like::
             return
 """
 supportsMatrix = {
-    '+restrictedEnum': 'postgres',
     '+exceptions': 'mysql sqlite',
-    '-transactions': 'mysql',
+    '-transactions': 'mysql rdbhost',
     '-dropTableCascade': 'sybase mssql',
-    '-fromDatabase': 'sqlite',
     '-expressionIndex': 'mysql sqlite firebird mssql',
-    '-blobData': 'mssql',
+    '-blobData': 'mssql rdbhost',
     '-decimalColumn': 'mssql',
     '-emptyTable': 'mssql',
-    '-limitSelect' : 'mssql'
+    '-limitSelect' : 'mssql',
+    '+schema' : 'postgres',
     }
 
 
@@ -271,6 +276,7 @@ def supports(feature):
         "The supportMatrix does not list this feature: %r"
         % feature)
 
+    
 # To avoid name clashes:
 _inserts = inserts
 
@@ -307,6 +313,17 @@ def teardown_module(mod=None):
     sqlobject.main.warnings_level = None
     sqlobject.main.exception_level = 0
 
+def setupLogging():
+    if not loggingModuleAvailable:
+        return
+    fmt = '[%(asctime)s] %(name)s %(levelname)s: %(message)s'
+    formatter = logging.Formatter(fmt)
+    hdlr = logging.StreamHandler(sys.stderr)
+    hdlr.setFormatter(formatter)
+    hdlr.setLevel(logging.NOTSET)
+    logger = logging.getLogger()
+    logger.addHandler(hdlr)
+
 __all__ = ['getConnection', 'getConnectionURI', 'setupClass', 'Dummy', 'raises',
            'd', 'inserts', 'supports', 'deprecated_module',
-           'setup_module', 'teardown_module']
+           'setup_module', 'teardown_module', 'setupLogging']
